@@ -41,9 +41,6 @@
 #   Affymetrix' Genotype Console v2.
 # }
 #
-# \examples{\dontrun{
-# }}
-#
 # @author
 #*/###########################################################################
 setConstructorS3("FragmentEquivalentClassNormalization", function(dataSet=NULL, ..., targetAvgs=NULL, subsetToFit="-XY") {
@@ -293,11 +290,11 @@ setMethodS3("getSubsetToFit", "FragmentEquivalentClassNormalization", function(t
   
         # Identify units to be excluded
         if (subsetToFit == "-X") {
-          subset <- getUnitsOnChromosome(gi, 23, .checkArgs=FALSE);
+          subset <- getUnitsOnChromosomes(gi, 23, .checkArgs=FALSE);
         } else if (subsetToFit == "-Y") {
-          subset <- getUnitsOnChromosome(gi, 24, .checkArgs=FALSE);
+          subset <- getUnitsOnChromosomes(gi, 24, .checkArgs=FALSE);
         } else if (subsetToFit == "-XY") {
-          subset <- getUnitsOnChromosome(gi, 23:24, .checkArgs=FALSE);
+          subset <- getUnitsOnChromosomes(gi, 23:24, .checkArgs=FALSE);
         }
   
         verbose && cat(verbose, "Units to exclude: ");
